@@ -13,6 +13,30 @@ def get_delivery_order_process_type_dic():
         10: "Recepción Física TL (Nuevo Formato)",
     }
     
+def get_lob_order_dic():
+    return {
+        1: "Entrega",
+        2: "Retorno"        
+    }
+    
+def get_delivery_order_status_description_dic():
+    return {
+        1: "En proceso de planificación",
+        4: "En proceso de planificación",
+        5: "Recibida por el tren logístico",
+        7: "Rechazada por el tren logístico o B2B",
+        9: "Entrega en Tránsito a base de distribución",
+        10: "Entrega Recibida en base de distribución",
+        12: "Entrega Agendada con validación de B2C",
+        13: "Entrega Agendada sin validación de B2C",
+        16: "Entrega lista para visitar al B2C",
+        17: "Entrega en Ruta hacia el cliente B2C",
+        19: "En espera de poner en tránsito para próximo intento de entrega",
+        25: "Superó los 3 intentos",
+        32: "Recibida en el centro de distribución",
+        33: "Recibida por personal que hará entrega al B2C",
+    }
+    
 def get_delivery_order_status_dic():
     return {
         1: "Planificación",
@@ -61,6 +85,11 @@ def get_delivery_order_status_dic():
         44: "Entregada B2B"
     }
 
+class LineOfBusinessType(Enum):
+    Delivery = 1
+    Pickup = 2
+    
+LOB_TYPES = [e.value for e in LineOfBusinessType]
 
 class DeliveryOrderProcessType(Enum):
     B2bDelivery = 1
@@ -133,9 +162,9 @@ class DeliveryOrderStatusType(Enum):
     ALASRejected = 36
     Steal = 37
     Missing  = 38    
-    Picking = 39
-    NotPicking = 40
-    NotPickingable = 41
+    Withdrawn = 39 #Picking = 39
+    NotWithdrawn = 40 #NotPicking = 40
+    Nonwithdrable = 41 #NotPickingable = 41
     DistributionCenterTravelling = 42
     B2BTraveling = 43
     B2BDelivered = 44
@@ -276,20 +305,14 @@ PICKUP_ORDER_STATE_MACHINE = {
         DeliveryOrderStatusType.DeliveryCourierReceived.value #Recibido Mensajero
     ],
     DeliveryOrderStatusType.DeliveryCourierReceived.value: [
-        DeliveryOrderStatusType.Picking.value, # Retirada
-        DeliveryOrderStatusType.NotPicking.value, # No Retirada        
-        DeliveryOrderStatusType.B2BReceptionRejected.value, #rechazado b2b
-        DeliveryOrderStatusType.B2CReceptionRejected.value, # rechazado cliente
-        DeliveryOrderStatusType.ALASRejected.value, # rechazado alas
-        DeliveryOrderStatusType.Steal.value, #robada
-        DeliveryOrderStatusType.Missing.value, #extraviada
+        DeliveryOrderStatusType.Withdrawn.value, # Retirada
+        DeliveryOrderStatusType.NotWithdrawn.value # No Retirada 
     ],
-    DeliveryOrderStatusType.NotPicking.value: [
-        DeliveryOrderStatusType.VirtuallyReceived.value,
-        DeliveryOrderStatusType.NotPickingable.value,
-        DeliveryOrderStatusType.Recovered.value
+    DeliveryOrderStatusType.NotWithdrawn.value: [
+        DeliveryOrderStatusType.DeliveryCourierReceived.value,
+        DeliveryOrderStatusType.Nonwithdrable.value
     ],
-    DeliveryOrderStatusType.Picking.value: [
+    DeliveryOrderStatusType.Withdrawn.value: [
         DeliveryOrderStatusType.SERReceived.value
     ],
     DeliveryOrderStatusType.SERReceived.value: [
@@ -305,7 +328,7 @@ PICKUP_ORDER_STATE_MACHINE = {
         DeliveryOrderStatusType.B2BDelivered.value
     ],
     DeliveryOrderStatusType.B2BDelivered.value: [
-        DeliveryOrderStatusType.Recovered.value
+        
     ],
     DeliveryOrderStatusType.B2CReceptionRejected.value: [ # rechazado cliente
         DeliveryOrderStatusType.Recovered.value
@@ -319,7 +342,7 @@ PICKUP_ORDER_STATE_MACHINE = {
     DeliveryOrderStatusType.Missing.value: [ # extraviada
         DeliveryOrderStatusType.Recovered.value
     ],
-    DeliveryOrderStatusType.NotPickingable.value: [
+    DeliveryOrderStatusType.Nonwithdrable.value: [
         DeliveryOrderStatusType.Recovered.value
     ],
     DeliveryOrderStatusType.Recovered.value: [
@@ -360,6 +383,7 @@ def get_delivery_rejected_reason_dic():
         9: "Compra Anulada",
         10: "Orden Duplicada",
         11: "Paquete Dañado",
+        12: "Retiro Anulado",
         14: "Sin Stock Para Remaquilar"
     }
 
@@ -444,6 +468,9 @@ def get_status(delivery_order):
     status = get_delivery_order_status_dic()
     return status[delivery_order['status']]
 
+def get_lob(delivery_order):
+    lob = get_lob_order_dic()
+    return lob[delivery_order['lob']] if 'lob' in delivery_order else lob[1]
 
 class DeliveryOrderRequestClient(EntityClientBase):
     entity_endpoint_base_url = '/delivery/delivery-order-requests/'
@@ -490,14 +517,14 @@ class DeliveryOrderClient(EntityClientBase):
     def change_planning(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-planning".format(id), params)
 
-    def upload_file(self, user_name, sender_code, base64_content, file_format="txt", file_name=None, family=1):
+    def upload_file(self, user_name, sender_code, base64_content, file_format="txt", file_name=None, lob=1):
         params = {
             'user_name': user_name,
             'sender_code': sender_code,
             'base64_content': base64_content,
             'format': file_format,
             'file_name': file_name,
-            'family': family
+            'lob': lob
         }
         return self.http_post_json(self.entity_endpoint_base_url + "_upload-file", params)
 
@@ -562,9 +589,15 @@ class DeliveryOrderClient(EntityClientBase):
 
     def validate_package(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_validate-package".format(id), params)
+    
+    def assign_package(self, id, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_assign-package".format(id), params)
 
     def process_create_labels_by_ids(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_process-create-labels-by-ids", params)
+    
+    def process_create_generic_labels(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_process-create-generic-labels", params)
 
     def create_label_sync(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_create-label-sync".format(id), params)
@@ -597,8 +630,11 @@ class DeliveryOrderClient(EntityClientBase):
     def delivery_courier_receive(self, id, event_info, pasync=True):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_delivery-courier-receive".format(id), event_info)
     
-    def pickup_receive(self, id, params):
-        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_pickup-receive".format(id), params)
+    def b2b_travelling(self, id, event_info):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_b2b-travelling".format(id), event_info)
+    
+    def b2b_receive(self, id, event_info):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_b2b-receive".format(id), event_info)
     # endregion
 
     def search_batch(self, search_info):
